@@ -11,6 +11,13 @@ logger.addHandler(ch)
 
 from .tools import *
 
-from ._version import get_versions
-__version__ = get_versions()['version']
-del get_versions
+try:
+    from importlib.metadata import version, PackageNotFoundError
+except ImportError:  # < Python 3.8: Use backport module
+    from importlib_metadata import version, PackageNotFoundError
+
+try:
+    __version__ = version(__name__)
+    del version
+except PackageNotFoundError:
+    pass
